@@ -93,9 +93,10 @@ class AllocationsTest(utils.TestCase):
             'geographic_requirements': 'near the beach',
             'ncris_support': 'some',
             'nectar_support': 'little',
-            'usage_pattterns': 'sporadic',
+            'usage_patterns': 'sporadic',
             'convert_trial_project': True,
             'notifications': False,
+            'managed': False,
         }
 
         a = self.cs.allocations.create(**data)
@@ -121,11 +122,13 @@ class AllocationsTest(utils.TestCase):
             'geographic_requirements': '',
             'ncris_support': '',
             'nectar_support': '',
-            'usage_pattterns': '',
+            'usage_patterns': '',
             'convert_trial_project': False,
             'notifications': True,
             'associated_site': None,
             'national': False,
+            'notifications': True,
+            'managed': True,
         }
 
         a = self.cs.allocations.create(**data)
@@ -160,3 +163,8 @@ class AllocationsTest(utils.TestCase):
         a = self.cs.allocations.get(123)
         quota = a.get_allocated_octavia_quota()
         self.assertEqual({'load_balancers': 7}, quota)
+
+    def test_get_allocated_magnum_quota(self):
+        a = self.cs.allocations.get(123)
+        quota = a.get_allocated_magnum_quota()
+        self.assertEqual({'clusters': 1}, quota)
