@@ -158,6 +158,16 @@ class Allocation(base.Resource):
                 kwargs['load_balancers'] = quota.quota
         return kwargs
 
+    def get_allocated_magnum_quota(self):
+        quotas = self.get_quota('container-infra')
+        if not quotas:
+            return {}
+        kwargs = {}
+        for quota in quotas:
+            quota_resource = quota.resource.split('.')[1]
+            kwargs[quota_resource] = quota.quota
+        return kwargs
+
 
 class AllocationManager(base.Manager):
 
@@ -197,8 +207,9 @@ class AllocationManager(base.Manager):
                field_of_research_3=None,
                for_percentage_1=0, for_percentage_2=0, for_percentage_3=0,
                geographic_requirements='', ncris_support='', nectar_support='',
-               usage_pattterns='', convert_trial_project=False,
-               associated_site=None, national=False, notifications=True):
+               usage_patterns='', convert_trial_project=False,
+               associated_site=None, national=False, notifications=True,
+               managed=True):
         # Backwards compatibility logic for 'allocation_home' is handled
         # server-side. Maybe we should warn the app that they are
         # using a deprecated feature
@@ -225,8 +236,9 @@ class AllocationManager(base.Manager):
             'geographic_requirements': geographic_requirements,
             'ncris_support': ncris_support,
             'nectar_support': nectar_support,
-            'usage_pattterns': usage_pattterns,
+            'usage_patterns': usage_patterns,
             'notifications': notifications,
+            'managed': managed,
         }
         return self._create('/allocations/', data=data)
 
